@@ -35,12 +35,11 @@ if (my $s = $headval->{slot_free}) {
     &out_list($s, 'free_slot');
 }
 
-sub out_list { my($cur, $type, $next) = @_;
-    $next ||= 'next_slot';
+sub out_list { my($cur, $type) = @_;
     my $slot = $f->slot($cur, $type);
     while (1) {
 	&out_struct($slot);
-	if ($cur = $slot->value->{$next}) {
+	if ($cur = $slot->value->{'next_slot'}) {
 	    $slot = $f->slot($cur, $type);
 	} else {
 	    last;
@@ -49,13 +48,18 @@ sub out_list { my($cur, $type, $next) = @_;
     }
 }
 
+&out_head('FE Running');
+if (my $s = $headval->{fe_run_head}) {
+    &out_list($s, 'fe_slot');
+}
+
 &out_head('Group List');
 if (my $g = $headval->{group_head}) {
     my $gr = $f->slot($g, 'gr_slot');
     while (1) {
 	&out_struct($gr);
 	$indent += $sw;
-	if (my $n = $gr->value->{name}) {
+	if (my $n = $gr->value->{name_slot}) {
 	    &out_head('Name');
 	    my $slot = $f->slot($n, 'grnm_slot');
 	    &out_struct($slot);
@@ -65,17 +69,13 @@ if (my $g = $headval->{group_head}) {
 	    &out_list($s, 'scr_slot');
 	}
 	&out_head('FE Wait List');
-	if (my $s = $gr->value->{fe_wait}) {
+	if (my $s = $gr->value->{fe_head}) {
 	    &out_list($s, 'fe_slot');
 	}
 	&out_head('BE List');
 	if (my $s = $gr->value->{be_head}) {
 	    &out_list($s, 'be_slot');
 	}
-	&out_head('BE Wait List');
-	if (my $s = $gr->value->{be_wait}) {
-	    &out_list($s, 'be_slot', 'be_wait_next');
-	}
 	$indent -= $sw;
 	if (my $n = $gr->value->{next_slot}) {
 	    $gr = $f->slot($n, 'gr_slot');
