@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002  Sam Horrocks
+ * Copyright (C) 2003  Sam Horrocks
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,9 +25,10 @@
 #define speedy_memmove(d,s,n)	memmove(d,s,n)
 #define speedy_bzero(s,n)	memset(s,'\0',n)
 #define speedy_free(s)		free(s)
-#define speedy_new(s,n,t)	do {(s) = (t*)malloc((n)*sizeof(t));} while (0)
+#define speedy_new(s,n,t)	\
+    do { (s) = (t*)malloc((n)*sizeof(t)); } while (0)
 #define speedy_renew(s,n,t)	\
-	do {(s) = (t*)realloc((s),(n)*sizeof(t));} while (0)
+    do {(s) = (t*)realloc((s),(n)*sizeof(t));} while (0)
 
 void speedy_abort(const char *s);
 int  speedy_execvp(const char *filename, const char *const *argv);
